@@ -49,6 +49,8 @@ private:
     QString f8;
 
 private slots:
+    void on_horizontalSlider_4_valueChanged(int value);
+    void on_Opacity_editingFinished();
     void on_font8_editingFinished();
     void on_font7_editingFinished();
     void on_fontbuttonpressed_clicked();
